@@ -1,10 +1,10 @@
-# BSD 3-Clause License; see https://github.com/scikit-hep/uproot4/blob/main/LICENSE
+# BSD 3-Clause License; see https://github.com/scikit-hep/uproot5/blob/main/LICENSE
 
 """
 This module defines the behaviors of ``TBranchElement``, which is entirely inherited from
 functions in :doc:`uproot.behaviors.TBranch.TBranch`.
 """
-
+from __future__ import annotations
 
 import uproot
 
@@ -24,5 +24,3 @@ class TBranchElement(uproot.behaviors.TBranch.TBranch):
         my_branchelement["subbranch"]["subsubbranch"]
         my_branchelement["subbranch/subsubbranch"]
     """
-
-    pass
